@@ -2,6 +2,7 @@ export * from './User';
 export * from './UserRecentlyViewedPatient';
 export * from './UserPreference';
 export * from './LocalSystemFact';
+export * from './Device';
 
 export * from './Patient';
 export * from './PatientFamilyHistory';
@@ -35,6 +36,8 @@ export * from './ReferenceDataRelation';
 export * from './VitalLog';
 export * from './Vitals';
 export * from './Procedure';
+export * from './ProcedureAssistantClinician';
+export * from './ProcedureSurveyResponse';
 
 export * from './EncounterDiagnosis';
 export * from './Prescription';
@@ -88,6 +91,7 @@ export * from './Department';
 export * from './Location';
 export * from './LocationGroup';
 export * from './UserFacility';
+export * from './ProcedureTypeSurvey';
 export * from './Attachment';
 export * from './UserLocalisationCache';
 export * from './Asset';
@@ -116,6 +120,9 @@ export * from './MedicationAdministrationRecord';
 export * from './MedicationAdministrationRecordDose';
 export * from './ReferenceMedicationTemplate';
 
+export * from './PharmacyOrder';
+export * from './PharmacyOrderPrescription';
+
 export * from './Notification';
 
 export * from './Signer';
